#
# spec file for package ghc-tagged
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name tagged
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.8.9
Release:        1.3
Summary:        Haskell 98 phantom types to avoid unsafely passing dummy arguments
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
Haskell 98 phantom types to avoid unsafely passing dummy arguments.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Dec  3 2024 Peter Simons <psimons@suse.com>
- Update tagged to version 0.8.9.
  0.8.9 [2024.12.03]
  - -----------------
  * Allow building with GHC 9.12.
  * Drop support for GHC 7.10 and earlier.
* Sat Mar 16 2024 Peter Simons <psimons@suse.com>
- Update tagged to version 0.8.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug  8 2023 Peter Simons <psimons@suse.com>
- Update tagged to version 0.8.8.
  0.8.8 [2023.08.08]
  - -----------------
  * Allow building with GHC 9.8.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Feb 18 2023 Peter Simons <psimons@suse.com>
- Update tagged to version 0.8.7.
  0.8.7 [2023.02.18]
  - -----------------
  * Define `Foldable1` and `Bifoldable1` instances for `Tagged`. These instances
    were originally defined in the `semigroupoids` library, and they have now
    been migrated to `tagged` as a side effect of adapting to
    [this Core Libraries Proposal](https://github.com/haskell/core-libraries-committee/issues/9),
    which adds `Foldable1` and `Bifoldable1` to `base`.
* Sat Jul 23 2022 Peter Simons <psimons@suse.com>
- Update tagged to version 0.8.6.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jul 27 2021 psimons@suse.com
- Update tagged to version 0.8.6.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Apr 22 2021 psimons@suse.com
- Update tagged to version 0.8.6.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Dec 29 2020 psimons@suse.com
- Update tagged to version 0.8.6.1.
  0.8.6.1 [2020.12.28]
  - -------------------
  * Mark all modules as explicitly Safe or Trustworthy.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update tagged to version 0.8.6 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Aug 31 2020 psimons@suse.com
- Update tagged to version 0.8.6 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update tagged to version 0.8.6.
  0.8.6 [2018.07.02]
  - -----------------
  * Make the `Read(1)` instances for `Proxy` ignore the precedence argument,
    mirroring similar changes to `base`
    [here](http://git.haskell.org/ghc.git/commitdiff/8fd959998e900dffdb7f752fcd42df7aaedeae6e).
  * Fix a bug in the `Floating` instance for `Tagged` in which `logBase` was
    defined in terms of `(**)`.
  * Avoid incurring some dependencies when using recent GHCs.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
- Update Cabal file to revision 2.
  * add support for GHC 8.4.x
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Dec  8 2016 psimons@suse.com
- Update to version 0.8.5 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.8.5 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.8.4 revision 0 with cabal2obs.
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 0.8.4
  * Backport the Alternative, MonadPlus, and MonadZip instances for Proxy from base-4.9
  * Add Bits, FiniteBits, IsString, and Storable instances for Tagged
* Fri Jan 29 2016 mimi.vx@gmail.com
- update to 0.8.3
  * Manual Generic1 support to work around a bug in GHC 7.6
  * Invert the dependency to supply the Semigroup instance ourselves
    when building on GHC 8
* Sun Nov  8 2015 mimi.vx@gmail.com
- update to 0.8.2
  * deepseq support
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 0.8.1
  * Add KProxy to the backwards compatibility Data.Proxy module.
  * Add a Generic instance to Proxy.
  * Added Data.Proxy.TH, based on the code from Frames by Anthony Cowley.
  * Removed reproxy from Data.Proxy. This is a bad API decision, but it isn't present
  in GHC's Data.Proxy, and this makes the API more stable.
* Sat Apr 25 2015 mimi.vx@gmail.com
- update to 0.7.3
  * Support `Data.Bifunctor` in `base` for GHC 7.9+.
  * Fixed warning on GHC 7.8
  * Added `tagWith`.
* Wed Oct  9 2013 sbahling@suse.com
- Update to 0.7 using cabal-rpm template
* Fri Jun  8 2012 peter.trommler@ohm-hochschule.de
- use cabal2spec 0.25.5 spec file template
* Sat Jan 21 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
